@@ -1,7 +1,7 @@
 package Time::Duration::Parse::More;
 
 # ABSTRACT: parse natural language time duration expressions
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 our $AUTHORITY = 'cpan:MELO'; # AUTHORITY
 
 use strict;
@@ -42,12 +42,6 @@ sub _parse_duration {
   my ($expression) = @_;
   return unless defined $expression;
 
-  ## 'midnight' is uncacheable
-  if ($expression eq 'midnight') {
-    my ($sec, $min, $hour) = (localtime())[0 .. 2];
-    return (60 - $sec + (60 - $min - 1) * 60 + (24 - $hour - 1) * 60 * 60, 0);
-  }
-
   my $e = $expression;
 
   ### split up 1h2m3s...
@@ -64,8 +58,9 @@ sub _parse_duration {
   $e =~ s/\b(\d+):(\d+):(\d+)\b/$1h $2m $3s/g;
   $e =~ s/\b(\d+):(\d+)\b/$1h $2m/g;
 
-  my $duration = 0;
-  my $signal   = 1;
+  my $duration  = 0;
+  my $cacheable = 1;
+  my $signal    = 1;
   while ($e) {
     if    ($e =~ s/^plus\b(\s*,?)*//)  { $signal = 1 }
     elsif ($e =~ s/^minus\b(\s*,?)*//) { $signal = -1 }
@@ -76,12 +71,19 @@ sub _parse_duration {
       croak "Unit '$u' not recognized in '$m'" unless exists $units{$u};
       $duration += $signal * $n * $units{$u};
     }
+    elsif ($e =~ s/^midnight\b(\s*,?)*//) {
+      my ($sec, $min, $hour) = (localtime())[0 .. 2];
+      $duration += $signal * (60 - $sec + (60 - $min - 1) * 60 + (24 - $hour - 1) * 60 * 60);
+
+      ## 'midnight' is uncacheable
+      $cacheable = 0;
+    }
     else {
       croak("Could not parse '$e'");
     }
   }
 
-  return (sprintf('%.0f', $duration), 1);
+  return (sprintf('%.0f', $duration), $cacheable);
 }
 
 
@@ -91,7 +93,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =for :stopwords Pedro Melo ACKNOWLEDGEMENTS cpan testmatrix url annocpan anno bugtracker rt
 cpants kwalitee diff irc mailto metadata placeholders metacpan
@@ -102,7 +104,7 @@ Time::Duration::Parse::More - parse natural language time duration expressions
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
